/**
 * Copyright (c) 2011 - 2020 Montages AG, CEA LIST, Artal
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *    Svyatoslav Kovalsky (Montages) - initial API and implementation
 *    Michael Golubev (Montages) - #386838 - migrate to Xtend2
 *    Aurelien Didier (ARTAL) - aurelien.didier51@gmail.com - Bug 569174
 */
package impl.parsers;

import com.google.common.base.Objects;
import com.google.inject.Inject;
import com.google.inject.Singleton;
import java.util.Arrays;
import org.eclipse.papyrus.gmf.codegen.gmfgen.ExpressionLabelParser;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenChildLabelNode;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenCommonBase;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenExpressionInterpreter;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenLabel;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenParserImplementation;
import org.eclipse.papyrus.gmf.codegen.gmfgen.LabelModelFacet;
import org.eclipse.xtext.xbase.lib.Extension;
import xpt.Common_qvto;

@Singleton
@SuppressWarnings("all")
public class expression_qvto {
  @Inject
  @Extension
  private Common_qvto _common_qvto;
  
  public boolean isViewExpressionDefinedAndOcl(final GenCommonBase xptSelf) {
    LabelModelFacet labelModelFacet = this.getLabelModelfacet(xptSelf);
    return ((!Objects.equal(labelModelFacet, null)) && this.isParserViewExpressionDefinedAndOcl(labelModelFacet.getParser()));
  }
  
  protected boolean _isParserViewExpressionDefinedAndOcl(final ExpressionLabelParser xptSelf) {
    return ((!Objects.equal(xptSelf.getViewExpression(), null)) && this._common_qvto.oclIsKindOf(xptSelf.getViewExpression().getProvider(), GenExpressionInterpreter.class));
  }
  
  protected boolean _isParserViewExpressionDefinedAndOcl(final GenParserImplementation xptSelf) {
    return false;
  }
  
  private LabelModelFacet getLabelModelfacet(final GenCommonBase xptSelf) {
    LabelModelFacet _switchResult = null;
    boolean _matched = false;
    if (xptSelf instanceof GenChildLabelNode) {
      _matched=true;
      _switchResult = ((GenChildLabelNode)xptSelf).getLabelModelFacet();
    }
    if (!_matched) {
      if (xptSelf instanceof GenLabel) {
        _matched=true;
        _switchResult = ((GenLabel)xptSelf).getModelFacet();
      }
    }
    if (!_matched) {
      _switchResult = null;
    }
    return _switchResult;
  }
  
  public boolean isParserViewExpressionDefinedAndOcl(final GenParserImplementation xptSelf) {
    if (xptSelf instanceof ExpressionLabelParser) {
      return _isParserViewExpressionDefinedAndOcl((ExpressionLabelParser)xptSelf);
    } else if (xptSelf != null) {
      return _isParserViewExpressionDefinedAndOcl(xptSelf);
    } else {
      throw new IllegalArgumentException("Unhandled parameter types: " +
        Arrays.<Object>asList(xptSelf).toString());
    }
  }
}
